@@ -2,7 +2,7 @@ package Acme::MetaSyntactic::icao;
 use strict;
 use Acme::MetaSyntactic::List;
 our @ISA = qw( Acme::MetaSyntactic::List );
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 __PACKAGE__->init();
 
 our %Remote = (
@@ -33,6 +33,12 @@ Abigail, Philippe Bruhat (BooK)
 
 =item *
 
+2017-06-12 - v1.004
+
+Updated from the source web site in Acme-MetaSyntactic-Themes version 1.050.
+
+=item *
+
 2015-08-10 - v1.003
 
 Updated from the source web site in Acme-MetaSyntactic-Themes version 1.047.
@@ -148,7 +154,7 @@ EGDB EGDC EGDG EGDH EGDK EGDL EGDM EGDN EGDO EGDP EGDR EGDS EGDT EGDX
 EGDY EGEC EGED EGEF EGEG EGEH EGEN EGEO EGEP EGEQ EGER EGES EGET EGEW
 EGFC EGFE EGFF EGFH EGFP EGGA EGGC EGGD EGGF EGGG EGGN EGGO EGGP EGGR
 EGGW EGGX EGGY EGHA EGHB EGHC EGHD EGHE EGHF EGHG EGHH EGHI EGHJ EGHK
-EGHL EGHN EGHO EGHP EGHR EGHS EGHT EGHU EGHY EGJA EGJB EGJJ EGKA EGKB
+EGHL EGHN EGHO EGHP EGHQ EGHR EGHS EGHT EGHU EGHY EGJA EGJB EGJJ EGKA EGKB
 EGKD EGKE EGKG EGKH EGKK EGKM EGKR EGLA EGLB EGLC EGLD EGLF EGLG EGLI
 EGLJ EGLK EGLL EGLM EGLS EGLT EGLW EGMA EGMC EGMD EGMF EGMH EGMJ EGNA
 EGNB EGNC EGND EGNE EGNF EGNG EGNH EGNI EGNJ EGNL EGNM EGNO EGNR EGNS
@@ -202,7 +208,7 @@ FBTS FBXB FBXG FCBB FCBD FCBG FCBK FCBL FCBM FCBO FCBS FCBT FCBU FCBV
 FCBY FCBZ FCCC FCMD FCMF FCMK FCML FCMM FCMN FCMO FCMR FCMT FCMY FCOB
 FCOE FCOG FCOI FCOK FCOL FCOM FCOO FCOS FCOT FCOU FCPA FCPB FCPD FCPE
 FCPG FCPI FCPK FCPL FCPM FCPN FCPP FCPY FDBM FDBS FDLV FDMB FDMH FDMS
-FDNG FDNH FDSM FDST FDTB FDTM FDUB FEFA FEFB FEFF FEFG FEFI FEFL FEFM
+FDNG FDNH FDSK FDSM FDST FDTB FDTM FDUB FEFA FEFB FEFF FEFG FEFI FEFL FEFM
 FEFN FEFO FEFR FEFS FEFT FEFY FGBT FGSL FHAW FIMP FIMR FJDG FKAB FKAF
 FKAG FKAL FKAM FKAN FKAO FKAY FKKA FKKB FKKC FKKD FKKF FKKI FKKM FKKN
 FKKR FKKU FKKV FKKY FKYS FLBA FLCH FLCP FLIK FLKB FLKO FLKS FLKW FLLC
@@ -318,9 +324,9 @@ KISM KISN KISO KISP KISQ KISS KISW KITH KITR KIVH KIWA KIWD KIWI KIWS
 KIXD KIYK KIZG KJAC KJAE KJAJ KJAN KJAO KJAS KJAX KJBC KJBK KJBP KJBR
 KJBS KJBT KJCC KJCE KJCI KJCT KJCX KJCY KJDM KJDN KJDT KJDX KJDY KJEF
 KJEM KJFK KJFN KJGC KJGL KJGP KJGQ KJGX KJHC KJHM KJHW KJHY KJI0 KJID
-KJKL KJKV KJLA KJLB KJLH KJLN KJLX KJMA KJMC KJMD KJMH KJMN KJMS KJNH
+KJKL KJLA KJLB KJLH KJLN KJLX KJMA KJMC KJMD KJMH KJMN KJMS KJNH
 KJNP KJNW KJOA KJOB KJOC KJOR KJOT KJPD KJPN KJPT KJRA KJRB KJRC KJRD
-KJRE KJSD KJSG KJSK KJSL KJSN KJST KJTO KJUC KJUP KJVI KJVL KJWC KJWH
+KJRE KJSD KJSG KJSK KJSL KJSN KJSO KJST KJTO KJUC KJUP KJVI KJVL KJWC KJWH
 KJWL KJWX KJXN KJYO KKAE KKAL KKBC KKBE KKBK KKBW KKCC KKCG KKCK KKCL
 KKCN KKCQ KKCR KKDK KKEB KKEH KKEK KKEU KKFP KKGK KKGX KKGZ KKIB KKIC
 KKIP KKKA KKKB KKKF KKKH KKKI KKKK KKKL KKKT KKKU KKLG KKLL KKLN KKLP
@@ -409,7 +415,7 @@ KUCE KUCY KUDD KUES KUEX KUGB KUGI KUGN KUGS KUIL KUIN KUIZ KUKI KUKN
 KUKT KULM KUMB KUMM KUMP KUMT KUNO KUNS KUNU KUNV KUOS KUOX KUPP KUQE
 KUSC KUST KUTO KUTS KUUK KUUU KUVA KUWA KVAD KVAK KVAY KVBG KVCB KVCT
 KVCV KVDI KVDU KVEE KVEL KVEX KVGT KVHN KVIH KVIK KVIS KVJI KVKS KVKW
-KVLA KVLD KVLO KVNC KVNY KVOK KVPC KVPS KVPZ KVQN KVRB KVRS KVRX KVSF
+KVLA KVLD KVLO KVNC KVNY KVOK KVPC KVPS KVPZ KVQN KVQQ KVRB KVRS KVRX KVSF
 KVTN KVTX KVUO KVUW KVYS KWAA KWAH KWAL KWAY KWBB KWBI KWBN KWBQ KWBR
 KWBU KWBW KWCR KWDB KWDD KWDG KWDN KWDR KWDY KWEA KWEY KWFB KWFK KWGO
 KWHD KWHH KWHP KWHT KWJF KWKK KWKL KWLB KWLD KWLK KWLM KWLN KWLR KWLW
@@ -476,7 +482,7 @@ MMCS MMCU MMCV MMCZ MMDA MMDM MMDO MMEP MMGL MMGM MMGT MMHO MMIA MMIO
 MMLC MMLM MMLO MMLP MMLT MMMA MMMD MMML MMMM MMMT MMMV MMMX MMMY MMMZ
 MMNL MMOX MMPB MMPG MMPN MMPR MMPS MMQT MMRX MMSD MMSP MMTC MMTG MMTJ
 MMTL MMTM MMTO MMTP MMTU MMUN MMVA MMVR MMZC MMZH MMZM MMZO MMZP MNBL
-MNCH MNJG MNJU MNMG MNPC MNRS MPBO MPDA MPFS MPHO MPLB MPMG MPNU MPSA
+MNCH MNJG MNJU MNMG MNPC MNRS MPBO MPDA MPFS MPHO MPLB MPMG MPNU MPSA MPSM
 MPTO MRBA MRCH MRLB MRLM MRNC MROC MRPM MRPV MSAC MSLP MSSA MSSM MSSS
 MTCH MTPP MUBA MUBY MUCA MUCC MUCF MUCL MUCM MUCU MUGM MUGT MUHA MUHG
 MULM MUMJ MUMO MUMZ MUNC MUNG MUPR MUSC MUSJ MUSN MUSS MUTD MUVR MUVT
@@ -536,7 +542,7 @@ RJOB RJOC RJOE RJOF RJOH RJOI RJOK RJOM RJOO RJOP RJOR RJOS RJOT RJOW
 RJOY RJOZ RJSA RJSC RJSD RJSF RJSH RJSI RJSK RJSM RJSN RJSO RJSS RJST
 RJSU RJSY RJTA RJTC RJTD RJTE RJTF RJTH RJTI RJTJ RJTK RJTL RJTO RJTQ
 RJTR RJTT RJTU RJTX RJTY RKJJ RKJK RKJY RKNC RKND RKNF RKNH RKNN RKNO
-RKNR RKNW RKPC RKPE RKPK RKPM RKPS RKPU RKSC RKSD RKSF RKSG RKSH RKSI
+RKNR RKNW RKNY RKPC RKPE RKPK RKPM RKPS RKPU RKSC RKSD RKSF RKSG RKSH RKSI
 RKSJ RKSL RKSM RKSO RKSP RKSQ RKSS RKST RKSU RKSV RKSW RKSX RKSY RKTA
 RKTB RKTD RKTE RKTF RKTG RKTH RKTI RKTM RKTN RKTP RKTS RKTT RKTU RKTV
 RKTW RKTY RKXX ROAH RODE RODN ROHF ROIG ROKJ ROMD ROMY RORA RORH RORK
@@ -568,8 +574,9 @@ SKLC SKLT SKMD SKMR SKMU SKNV SKPC SKPE SKPP SKPS SKPV SKRG SKRH SKSE
 SKSJ SKSM SKSP SKUC SKUI SKVP SKVV SLAP SLAS SLBJ SLCA SLCB SLCH SLCN
 SLCO SLCP SLET SLGY SLJE SLJO SLJV SLLP SLMG SLOR SLPO SLPS SLRA SLRB
 SLRI SLRQ SLRY SLSA SLSB SLSI SLSM SLSU SLTI SLTJ SLTR SLVM SLVR SLYA
-SMJP SMZO SMZY SOCA SOOM SPAY SPCL SPDO SPEO SPEQ SPGM SPHI SPHO SPHY
-SPHZ SPIM SPJA SPJI SPJL SPJN SPJR SPME SPMS SPNC SPPY SPQT SPQU SPRU
+SMJP SMZO SMZY SOCA SOOM SPAO SPAR SPAY SPBB SPBR SPBS SPCL SPDO SPEO
+SPEQ SPGM SPHI SPHO SPHY SPHZ SPIL SPIM SPJA SPJI SPJJ SPJL SPJN SPJR
+SPLN SPLO SPME SPMR SPMS SPNC SPOA SPOV SPPY SPQT SPQU SPRU
 SPSO SPST SPTN SPTU SPUR SPYL SPZO SUAA SUAG SUCA SUDU SULS SUME SUMO
 SUMU SUPE SUPU SURV SUSO SUTB SUTR SVAC SVAN SVBC SVBI SVBM SVBS SVCB
 SVCD SVCL SVCN SVCO SVCP SVCR SVCS SVCU SVED SVEZ SVFM SVGD SVGI SVGU
@@ -609,12 +616,12 @@ VYDW VYGG VYGW VYHH VYHL VYKG VYKP VYKT VYKU VYLK VYLS VYMD VYMK VYML
 VYMM VYMN VYMO VYMS VYMT VYMU VYMW VYNS VYNT VYPA VYPG VYPK VYPN VYPP
 VYPT VYPU VYRN VYRR VYSW VYSY VYTD VYYE VYYY WAAA WAAB WAAS WAAU WABB
 WABI WABN WABO WABT WADD WAJI WAJJ WAJW WAKK WAKT WAMA WAME WAMG WAMH
-WAMI WAML WAMM WAMP WAMT WAMW WAPA WAPH WAPI WAPN WAPP WAPR WASF WASK
+WAMI WAML WAMM WAMP WAMT WAMW WAOK WAPA WAPH WAPI WAPN WAPP WAPR WASF WASK
 WASR WASS WBGB WBGG WBGR WBGS WBKK WBKL WBKS WBKT WBKW WBSB WIAA WIAG
 WIAM WIAR WIAS WIBB WIDD WIDN WIIA WIIB WIIH WIII WIIJ WIIK WIIL WIIS
 WIIT WIKD WIKK WIKS WIMB WIMG WIMM WIMS WIOI WIOK WION WIOO WIOS WIPA
 WIPH WIPL WIPP WIPR WIPT WITC WITM WITT WMBA WMKA WMKC WMKD WMKI WMKJ
-WMKK WMKL WMKM WMKN WMKP WMSA WPDL WPEC WPOC WRBB WRBI WRBK WRBM WRBP
+WMKK WMKL WMKM WMKN WMKP WMSA WPDL WPEC WPOC WRBB WRBI WRBM WRBP
 WRKC WRKK WRKL WRKM WRKR WRKS WRLB WRLG WRLK WRLL WRLR WRLS WRRA WRRB
 WRRS WRRW WRSJ WRSP WRSQ WRSS WSAP WSAT WSSL WSSS YAYE YBAF YBAM YBAS
 YBBN YBCG YBCS YBCV YBGL YBLR YBMA YBMC YBMK YBOK YBPN YBRK YBRM YBTL
