@@ -21,10 +21,29 @@ L<http://www.nntp.perl.org/group/perl.perl5.porters/116654>.
 
 Abigail
 
-Introduced in Acme-MetaSyntactic version 0.94, published on October 2, 2006.
+=head1 CHANGES
 
-Received its own version number for Acme-MetaSyntactic-Themes version 1.000,
-published on May 7, 2012.
+=over 4
+
+=item *
+
+2012-05-07 - v1.000
+
+Received its own version number in Acme-MetaSyntactic-Themes version 1.000.
+
+=item *
+
+2006-10-02
+
+Introduced in Acme-MetaSyntactic version 0.94.
+
+=item *
+
+2006-09-27
+
+Submitted by Abigail.
+
+=back
 
 =head1 SEE ALSO
 
